==> cminpack-1.3.8-3-x86_64.pkg.tar.zst: usr/share/cminpack/CMinpackConfig-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "cminpack::cminpacks" for configuration "Release"
set_property(TARGET cminpack::cminpacks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpacks PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpacks.so.1.3.8"
  IMPORTED_SONAME_RELEASE "libcminpacks.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS cminpack::cminpacks )
list(APPEND _IMPORT_CHECK_FILES_FOR_cminpack::cminpacks "${_IMPORT_PREFIX}/lib/libcminpacks.so.1.3.8" )

# Import target "cminpack::cminpack" for configuration "Release"
set_property(TARGET cminpack::cminpack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpack.so.1.3.8"
  IMPORTED_SONAME_RELEASE "libcminpack.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS cminpack::cminpack )
list(APPEND _IMPORT_CHECK_FILES_FOR_cminpack::cminpack "${_IMPORT_PREFIX}/lib/libcminpack.so.1.3.8" )

# Import target "cminpack::cminpackld" for configuration "Release"
set_property(TARGET cminpack::cminpackld APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpackld PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpackld.so.1.3.8"
  IMPORTED_SONAME_RELEASE "libcminpackld.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS cminpack::cminpackld )
list(APPEND _IMPORT_CHECK_FILES_FOR_cminpack::cminpackld "${_IMPORT_PREFIX}/lib/libcminpackld.so.1.3.8" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> cminpack-1.3.9-1-x86_64.pkg.tar.zst: usr/share/cminpack/CMinpackConfig-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "cminpack::cminpacks" for configuration "Release"
set_property(TARGET cminpack::cminpacks APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpacks PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpacks.so.1.3.9"
  IMPORTED_SONAME_RELEASE "libcminpacks.so.1"
  )

list(APPEND _cmake_import_check_targets cminpack::cminpacks )
list(APPEND _cmake_import_check_files_for_cminpack::cminpacks "${_IMPORT_PREFIX}/lib/libcminpacks.so.1.3.9" )

# Import target "cminpack::cminpack" for configuration "Release"
set_property(TARGET cminpack::cminpack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpack.so.1.3.9"
  IMPORTED_SONAME_RELEASE "libcminpack.so.1"
  )

list(APPEND _cmake_import_check_targets cminpack::cminpack )
list(APPEND _cmake_import_check_files_for_cminpack::cminpack "${_IMPORT_PREFIX}/lib/libcminpack.so.1.3.9" )

# Import target "cminpack::cminpackld" for configuration "Release"
set_property(TARGET cminpack::cminpackld APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(cminpack::cminpackld PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libcminpackld.so.1.3.9"
  IMPORTED_SONAME_RELEASE "libcminpackld.so.1"
  )

list(APPEND _cmake_import_check_targets cminpack::cminpackld )
list(APPEND _cmake_import_check_files_for_cminpack::cminpackld "${_IMPORT_PREFIX}/lib/libcminpackld.so.1.3.9" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
